UrlInfoContentTypeResult class final

Retrive the determined given content types from UrlInfo.

Annotations
  • @immutable

Properties

hashCode → int
The hash code for this object.
no setterinherited
httpContentType → ContentTypeCategory
Determined content type from UrlInfo.url.
final
httpsContentType → ContentTypeCategory?
Determined content type from UrlInfo.secureUrl if provided.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
urlInfo → UrlInfo
Source of UrlInfo.
final

Methods

isEqualsCategory() → bool?
Check does httpContentType and httpsContentType are equals.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited